summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'png.h')
-rw-r--r--png.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/png.h b/png.h
index 06eb63fcb..90ae02acb 100644
--- a/png.h
+++ b/png.h
@@ -1,15 +1,15 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.0beta18 - December 8, 2006
- * Copyright (c) 1998-2006 Glenn Randers-Pehrson
+ * libpng version 1.4.0beta19 - May 15, 2007
+ * Copyright (c) 1998-2007 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.0beta18 - December 8, 2006: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -126,7 +126,7 @@
* 1.2.12 13 10212 12.so.0.10[.0]
* 1.4.0beta9-14 14 10400 14.so.0.0[.0]
* 1.2.13 13 10213 12.so.0.10[.0]
- * 1.4.0beta15-16 14 10400 14.so.0.0[.0]
+ * 1.4.0beta15-19 14 10400 14.so.0.0[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -156,8 +156,8 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.4.0beta18, December 8, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
*
@@ -268,13 +268,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 8, 2006
+ * May 15, 2007
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.4.0beta18 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -330,9 +330,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.0beta18"
+#define PNG_LIBPNG_VER_STRING "1.4.0beta19"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.0beta18 - December 8, 2006 (header)\n"
+ " libpng version 1.4.0beta19 - May 15, 2007 (header)\n"
#define PNG_LIBPNG_VER_SONUM 1
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -344,7 +344,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 18
+#define PNG_LIBPNG_VER_BUILD 19
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1343,7 +1343,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_0beta18;
+typedef png_structp version_1_4_0beta19;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,15 +1,15 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.0beta18 - December 8, 2006: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.0beta19 - May 15, 2007: Glenn
* See also "Contributing Authors", below.
*
@@ -156,8 +156,8 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta18, December 8, 2006, are
- * Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta19, May 15, 2007, are
+ * Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -268,13 +268,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.0beta18 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.0beta19 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*